.. _sdv.tabular.copulas:

.. currentmodule:: sdv.tabular.copulas

GaussianCopula
==============

.. autosummary::
   :toctree: api/

   GaussianCopula
   GaussianCopula.fit
   GaussianCopula.sample
   GaussianCopula.sample_conditions
   GaussianCopula.sample_remaining_columns
   GaussianCopula.get_metadata
   GaussianCopula.get_parameters
   GaussianCopula.set_parameters
   GaussianCopula.get_distributions
   GaussianCopula.get_likelihood
   GaussianCopula.save
   GaussianCopula.load
